# Changelog

## [0.4.0a1](https://github.com/OpenVoiceOS/ovos-core/tree/0.4.0a1) (2025-01-29)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-core/compare/0.3.8...0.4.0a1)

**Merged pull requests:**

- feat:multilang\_match [\#646](https://github.com/OpenVoiceOS/ovos-core/pull/646) ([JarbasAl](https://github.com/JarbasAl))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
